@@ -81,6 +81,8 @@ typedef gint64 goffset;
 #define G_GOFFSET_FORMAT        G_GINT64_FORMAT
 #define G_GOFFSET_CONSTANT(val) G_GINT64_CONSTANT(val)
 
+#define G_POLLFD_FORMAT "%d"
+
 
 #define GPOINTER_TO_INT(p)	((gint)  (gint) (p))
 #define GPOINTER_TO_UINT(p)	((guint) (guint) (p))
@@ -100,28 +102,14 @@ typedef unsigned int guintptr;
 #endif
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 46
-#define GLIB_MICRO_VERSION 2
+#define GLIB_MINOR_VERSION 48
+#define GLIB_MICRO_VERSION 0
 
 #define G_OS_UNIX
 
 
 #define G_VA_COPY	va_copy
 
-#ifdef	__cplusplus
-#define	G_HAVE_INLINE	1
-#else	/* !__cplusplus */
-#define G_HAVE_INLINE 1
-#define G_HAVE___INLINE 1
-#define G_HAVE___INLINE__ 1
-#endif	/* !__cplusplus */
-
-#ifdef	__cplusplus
-#define G_CAN_INLINE	1
-#else	/* !__cplusplus */
-#define G_CAN_INLINE	1
-#endif
-
 #ifndef __cplusplus
 # define G_HAVE_ISO_VARARGS 1
 #endif
